import React, { useState, useEffect } from 'react';

import AppBar from '@mui/material/AppBar';
import Avatar from '@mui/material/Avatar';
import Box from '@mui/material/Box';
import IconButton from '@mui/material/IconButton';
import Toolbar from '@mui/material/Toolbar';
import Typography from '@mui/material/Typography';
import ExitToAppIcon from '@mui/icons-material/ExitToApp';
import { Route, Router, Routes } from 'react-router-dom';
import ConfigContext, { config } from './Config';
import LoginForm from './LoginForm';
import Main from './Main';
import VideoPlayer from './VideoPlayer';
import { default as VuetifyLogo, default as VuetifyName } from './logo.svg';

import axios from 'axios';
import { useLocation, useNavigate } from 'react-router-dom';
import jwtDecode from 'jwt-decode';

axios.interceptors.request.use((config) => {
  const token = localStorage.getItem('token');
  if (token) {
    config.headers.Authorization = `Bearer ${token}`;
  }
  return config;
});

const App = () => {
  const navigate = useNavigate();
  const location = useLocation();

  const [username, setUsername] = useState('');

  useEffect(() => {
    const token = localStorage.getItem('token');
    if (token) {
      const decodedToken = jwtDecode(token);
      setUsername(decodedToken.username);
    }
  }, []);

  axios.interceptors.response.use(
    (response) => {
      return response;
    },
    (error) => {
      if (error.response.status === 401) {
        sessionStorage.setItem('previousLocation', location.pathname);
        navigate('/login');
      }
      return Promise.reject(error);
    }
  );

  const handleLogout = () => {
    localStorage.removeItem('token');
    setUsername('');
    navigate('/login');
  };

  return (
    <ConfigContext.Provider value={config}>
      <div>
        <AppBar position="static">
          <Toolbar>
            <Box display="flex" alignItems="center" flexGrow={1}>
              <IconButton edge="start" color="inherit" aria-label="menu">
                <img src={VuetifyLogo} alt="Vuetify Logo" width="40" />
              </IconButton>
          
            </Box>
            {username && (
              <Box display="flex" alignItems="center" marginRight="1rem">
                <Avatar>{username.charAt(0).toUpperCase()}</Avatar>
                <Typography variant="subtitle1" style={{ marginLeft: '1rem' }}>
                  {username}
                </Typography>
              </Box>
            )}
            <IconButton edge="end" color="inherit" aria-label="logout" onClick={handleLogout}>
              <ExitToAppIcon />
            </IconButton>
          </Toolbar>
        </AppBar>
      </div>
      <Routes>
        <Route path="/login" element={<LoginForm />} />
        <Route path="/" element={<Main />} />
        <Route path="/res/:filename" element={<VideoPlayer />} />
      </Routes>
    </ConfigContext.Provider>
  );
};

export default App;